package be.iminds.ilabt.jfed.espec.model;

import be.iminds.ilabt.jfed.espec.parser.ExperimentSpecificationParser;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.util.List;

/**
 * UploadLikeSpec
 */
public abstract class UploadLikeSpec {
    @Nullable protected final FileSource source;
    @Nullable protected final String path;
    @Nonnull protected final String permissions;
    @Nullable protected final List<String> nodes;

    public UploadLikeSpec(@Nullable FileSource source,
                          @Nullable String path,
                          @Nonnull String permissions,
                          @Nullable List<String> nodes) {
        //parser should check this, but another check here
        if (source == null && path == null)
            throw new IllegalArgumentException("must have either a source or a path");

        this.source = source;
        this.path = path;
        this.permissions = permissions;
        this.nodes = nodes;
    }

    @Nullable
    public FileSource getSource() {
        return source;
    }

    @Nullable
    public String getPath() {
        return path;
    }

    @Nonnull
    public String getPermissions() {
        return permissions;
    }

    @Nullable
    public List<String> getNodes() {
        return nodes;
    }

    /**
     * @return a simple description of the file or remote path involved. Only meant for describing the upload to humans.
     */
    @Nonnull
    public String getDesc() {
        return source != null ?
                source.getBasename() :
                (path != null ? path : "unknown");
    }
}
